@@ -83,11 +83,6 @@ void  daemonize() {
 
   pid_t pid;
 
-  /*
-   * Clear file creation mask
-   */
-  umask(0);
-
   /*
    * Become a session leader to lose our controlling terminal
    */
