@@ -85,6 +85,7 @@
 #include "system/Process.h"
 #include "util/Str.h"
 #include "util/StringBuffer.h"
+#include "system/NetStatistics.h"
 
 
 #define MONITRC            "monitrc"
@@ -98,14 +99,6 @@
 
 #define ARGMAX             64
 #define HTTP_CONTENT_MAX   (1024*1000)
-/* Set event queue directory mode: "drwx------" */
-#define QUEUEMASK          0077
-/* Set file mode: "drw-------" */
-#define PRIVATEMASK        0177
-/* Set log file mode: "-rw-r-----" */
-#define LOGMASK            0137
-/* Set pid file mode: "-rw-r--r--" */
-#define MYPIDMASK          0122
 #define MYPIDDIR           PIDDIR
 #define MYPIDFILE          "monit.pid"
 #define MYSTATEFILE        "monit.state"
@@ -124,7 +117,7 @@
 
 #define START_DELAY        0
 #define EXEC_TIMEOUT       30
-#define PROGRAM_TIMEOUT    600
+#define PROGRAM_TIMEOUT    300
 
 #define START_HTTP         1
 #define STOP_HTTP          2
@@ -164,6 +157,7 @@ typedef enum {
 #define TIME_MINUTE        60
 #define TIME_HOUR          3600
 #define TIME_DAY           86400
+#define TIME_MONTH         2678400
 
 #define ACTION_IGNORE      0
 #define ACTION_ALERT       1
@@ -182,6 +176,7 @@ typedef enum {
 #define TYPE_SYSTEM        5
 #define TYPE_FIFO          6
 #define TYPE_PROGRAM       7
+#define TYPE_NET           8
 
 #define RESOURCE_ID_CPU_PERCENT       1
 #define RESOURCE_ID_MEM_PERCENT       2
@@ -208,8 +203,8 @@ typedef enum {
 
 #define UNIT_BYTE          1
 #define UNIT_KILOBYTE      1024
-#define UNIT_MEGABYTE      1048580
-#define UNIT_GIGABYTE      1073740000
+#define UNIT_MEGABYTE      1048576
+#define UNIT_GIGABYTE      1073741824
 
 #define HASH_UNKNOWN       0
 #define HASH_MD5           1
@@ -651,6 +646,46 @@ typedef struct myuptime {
 } *Uptime_T;
 
 
+typedef struct mynetlinkstatus {
+        EventAction_T action;  /**< Description of the action upon event occurence */
+
+        /** For internal use */
+        struct mynetlinkstatus *next;                      /**< next link in chain */
+} *NetLinkStatus_T;
+
+
+typedef struct mynetlinkspeed {
+        int duplex;                                        /**< Last duplex status */
+        long long speed;                                     /**< Last speed [bps] */
+        EventAction_T action;  /**< Description of the action upon event occurence */
+
+        /** For internal use */
+        struct mynetlinkspeed *next;                       /**< next link in chain */
+} *NetLinkSpeed_T;
+
+
+typedef struct mynetlinksaturation {
+        Operator_Type operator;                           /**< Comparison operator */
+        float limit;                                     /**< Saturation limit [%] */
+        EventAction_T action;  /**< Description of the action upon event occurence */
+
+        /** For internal use */
+        struct mynetlinksaturation *next;                  /**< next link in chain */
+} *NetLinkSaturation_T;
+
+
+typedef struct mybandwidth {
+        Operator_Type operator;                           /**< Comparison operator */
+        unsigned long long limit;                              /**< Data watermark */
+        int rangecount;                            /**< Time range to watch: count */
+        int range;                                  /**< Time range to watch: unit */
+        EventAction_T action;  /**< Description of the action upon event occurence */
+
+        /** For internal use */
+        struct mybandwidth *next;                     /**< next bandwidth in chain */
+} *Bandwidth_T;
+
+
 /** Defines checksum object */
 typedef struct mychecksum {
         MD_T  hash;                     /**< A checksum hash computed for the path */
@@ -699,6 +734,15 @@ typedef struct mygid {
 } *Gid_T;
 
 
+/** Defines pid object */
+typedef struct mypid {
+        EventAction_T action;  /**< Description of the action upon event occurence */
+
+        /** For internal use */
+        struct mypid *next;                                 /**< next pid in chain */
+} *Pid_T;
+
+
 /** Defines filesystem configuration */
 typedef struct myfilesystem {
         int  resource;                        /**< Whether to check inode or space */
@@ -762,6 +806,10 @@ typedef struct myinfo {
                         int    total_cpu_percent;                         /**< percentage * 10 */
                         time_t uptime;                                     /**< Process uptime */
                 } process;
+
+                struct {
+                        NetStatistics_T stats;
+                } net;
         } priv;
 } *Info_T;
 
@@ -801,14 +849,20 @@ typedef struct myservice {
         Match_T     matchlist;                             /**< Content Match list */
         Match_T     matchignorelist;                /**< Content Match ignore list */
         Timestamp_T timestamplist;                       /**< Timestamp check list */
+        Pid_T       pidlist;                                   /**< Pid check list */
+        Pid_T       ppidlist;                                 /**< PPid check list */
+        Status_T    statuslist;           /**< Program execution status check list */
         Uid_T       uid;                                            /**< Uid check */
         Uid_T       euid;                                 /**< Effective Uid check */
         Gid_T       gid;                                            /**< Gid check */
-        Status_T    statuslist;           /**< Program execution status check list */
+        NetLinkStatus_T netlinkstatuslist;           /**< Network link status list */
+        NetLinkSpeed_T netlinkspeedlist;              /**< Network link speed list */
+        NetLinkSaturation_T netlinksaturationlist;  /**< Net. link saturation list */
+        Bandwidth_T uploadbyteslist;                  /**< Upload bytes check list */
+        Bandwidth_T uploadpacketslist;              /**< Upload packets check list */
+        Bandwidth_T downloadbyteslist;              /**< Download bytes check list */
+        Bandwidth_T downloadpacketslist;          /**< Download packets check list */
 
-
-        EventAction_T action_PID;                      /**< Action upon pid change */
-        EventAction_T action_PPID;                    /**< Action upon ppid change */
         EventAction_T action_FSFLAG;      /**< Action upon filesystem flags change */
 
         /** General event handlers */
@@ -897,7 +951,6 @@ struct myrun {
         volatile int  doreload;    /**< TRUE if a monit daemon should reinitialize */
         volatile int  dowakeup;  /**< TRUE if a monit daemon was wake up by signal */
         int  doaction;             /**< TRUE if some service(s) has action pending */
-        mode_t umask;                /**< The initial umask monit was started with */
         time_t incarnation;              /**< Unique ID for running monit instance */
         int  handler_init;                  /**< The handlers queue initialization */
         int  handler_flag;                            /**< The handlers state flag */
@@ -991,7 +1044,7 @@ void  LogNotice(const char *, ...) __attribute__((format (printf, 1, 2)));
 void  LogInfo(const char *, ...) __attribute__((format (printf, 1, 2)));
 void  LogDebug(const char *, ...) __attribute__((format (printf, 1, 2)));
 void  vLogError(const char *s, va_list ap);
-void vLogAbortHandler(const char *s, va_list ap);
+void  vLogAbortHandler(const char *s, va_list ap);
 void  log_close();
 #ifndef HAVE_VSYSLOG
 #ifdef HAVE_SYSLOG
@@ -1025,6 +1078,7 @@ int  check_remote_host(Service_T);
 int  check_system(Service_T);
 int  check_fifo(Service_T);
 int  check_program(Service_T);
+int  check_net(Service_T);
 int  check_URL(Service_T s);
 int  sha_md5_stream (FILE *, void *, void *);
 void reset_procinfo(Service_T);
