@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -165,6 +165,9 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
     StringBuffer_T cmdline = StringBuffer_create(64);
     pt[i].pid       = pinfo[i].ki_pid;
     pt[i].ppid      = pinfo[i].ki_ppid;
+    pt[i].uid       = pinfo[i].ki_ruid;
+    pt[i].euid      = pinfo[i].ki_uid;
+    pt[i].gid       = pinfo[i].ki_rgid;
     pt[i].starttime = pinfo[i].ki_start.tv_sec;
     pt[i].cputime   = (long)(pinfo[i].ki_runtime / 100000);
     pt[i].mem_kbyte = (unsigned long)(pinfo[i].ki_rssize * pagesize_kbyte);
@@ -178,7 +181,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
     if ((args = kvm_getargv(kvm_handle, &pinfo[i], 0))) {
       for (int j = 0; args[j]; j++)
         StringBuffer_append(cmdline, args[j + 1] ? "%s " : "%s", args[j]);
-      pt[i].cmdline = Str_dup(StringBuffer_toString(StringBuffer_trim(cmdline))); 
+      pt[i].cmdline = Str_dup(StringBuffer_toString(StringBuffer_trim(cmdline)));
     }
     StringBuffer_free(&cmdline);
     if (! pt[i].cmdline || ! *pt[i].cmdline) {
@@ -213,24 +216,25 @@ int getloadavg_sysdep(double *loadv, int nelem) {
 int used_system_memory_sysdep(SystemInfo_T *si) {
   int                mib[16];
   size_t             len;
-  struct vmtotal     vm;
   int                n = 0;
   int                pagesize = getpagesize();
+  int                v_active_count;
   size_t             miblen;
   struct xswdev      xsw;
   unsigned long long total = 0ULL;
   unsigned long long used  = 0ULL;
 
   /* Memory */
-  memset(mib, 0, sizeof(mib));
-  mib[0] = CTL_VM;
-  mib[1] = VM_METER;
-  len    = sizeof(struct vmtotal);
-  if (sysctl(mib, 2, &vm, &len, NULL, 0) == -1) {
-    LogError("system statistic error -- cannot get real memory usage: %s\n", STRERROR);
+  len = sizeof(v_active_count);
+  if (sysctlbyname("vm.stats.vm.v_active_count", &v_active_count, &len, NULL, 0) == -1) {
+    LogError("system statistic error -- cannot get for real memory usage: %s\n", STRERROR);
     return FALSE;
   }
-  si->total_mem_kbyte = (unsigned long)(vm.t_arm * pagesize_kbyte);
+  if (len != sizeof(v_active_count)) {
+    LogError("system statistic error -- real memory usage statics error\n");
+    return FALSE;
+  }
+  si->total_mem_kbyte = v_active_count * pagesize_kbyte;
 
   /* Swap */
   memset(mib, 0, sizeof(mib));
