@@ -41,9 +41,9 @@
  */
 static char *_escapeZeroInExpectBuffer(char *s, int n) {
         assert(n < EXPECT_BUFFER_MAX);
+        int i, j;
         char t[n]; // VLA
-        memcpy(t, s, n);
-        for (int i = 0, j = 0; j <= n; i++, j++) {
+        for (i = 0, j = 0; j < n; i++, j++) {
                 if ((t[j] = s[i]) == '\0') {
                         if (j + 2 < n) {
                                 t[j] = '\\';
@@ -52,8 +52,10 @@ static char *_escapeZeroInExpectBuffer(char *s, int n) {
                         }
                 }
         }
-        memcpy(s, t, n);
-        s[n] = 0;
+        if (j > i) {
+                memcpy(s, t, n);
+                s[n] = 0;
+        }
         return s;
 }
 
@@ -100,7 +102,7 @@ int check_generic(Socket_T socket) {
                         /* Since the protocol is unknown we need to wait on EOF. To avoid waiting
                          timeout seconds on EOF we first read one byte to fill the socket's read 
                          buffer and then set a low timeout on next read which reads remaining bytes 
-                         as well as waiting on EOF */
+                         as well as wait on EOF */
                         *buf = socket_read_byte(socket);
                         if (*buf < 0) {
                                 socket_setError(socket, "GENERIC: error receiving data -- %s", STRERROR);
@@ -113,7 +115,7 @@ int check_generic(Socket_T socket) {
                         buf[n] = 0;
                         if (n > 0)
                                 _escapeZeroInExpectBuffer(buf, n);
-                        socket_setTimeout(socket, timeout); // Reset original timeout
+                        socket_setTimeout(socket, timeout); // Reset back original timeout for next send/expect
 #ifdef HAVE_REGEX_H
                         regex_return = regexec(g->expect, buf, 0, NULL, 0);
                         if (regex_return != 0) {
