@@ -61,7 +61,10 @@ typedef enum {
         Protocol_GPS,
         Protocol_RADIUS,
         Protocol_MEMCACHE,
-        Protocol_WEBSOCKET
+        Protocol_WEBSOCKET,
+        Protocol_REDIS,
+        Protocol_MONGODB,
+        Protocol_SIEVE
 } Protocol_Type;
 
 
@@ -76,13 +79,16 @@ int check_imap(Socket_T);
 int check_clamav(Socket_T);
 int check_ldap2(Socket_T);
 int check_ldap3(Socket_T);
+int check_mongodb(Socket_T);
 int check_mysql(Socket_T);
 int check_nntp(Socket_T);
 int check_ntp3(Socket_T);
 int check_postfix_policy(Socket_T);
 int check_pop(Socket_T);
+int check_sieve(Socket_T);
 int check_smtp(Socket_T);
 int check_ssh(Socket_T);
+int check_redis(Socket_T);
 int check_rdate(Socket_T);
 int check_rsync(Socket_T);
 int check_tns(Socket_T);
