@@ -1,5 +1,6 @@
 /*
- * Copyright (C) Tildeslash Ltd. All rights reserved.
+ * Public Domain SHA-1 in C By Steve Reid <sreid@sea-to-sky.net>
+ * Sub-licensed with modifications under AGPL:
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License version 3.
@@ -19,10 +20,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
- */
-/*
- * Based on 100% Public Domain SHA-1 in C By Steve Reid <sreid@sea-to-sky.net>
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -105,9 +103,6 @@ static void sha1_transform(unsigned int state[5], const unsigned char buffer[64]
         state[2] += c;
         state[3] += d;
         state[4] += e;
-
-        /* Wipe variables */
-        a = b = c = d = e = 0;
 }
 
 
