@@ -128,6 +128,7 @@
 #include "alert.h"
 #include "process.h"
 #include "event.h"
+#include "state.h"
 
 
 struct ad_user {
@@ -235,6 +236,10 @@ static void printevents(unsigned int events) {
         } else {
                 if (IS_EVENT_SET(events, Event_Action))
                         printf("Action ");
+                if (IS_EVENT_SET(events, Event_ByteIn))
+                        printf("ByteIn ");
+                if (IS_EVENT_SET(events, Event_ByteOut))
+                        printf("ByteOut ");
                 if (IS_EVENT_SET(events, Event_Checksum))
                         printf("Checksum ");
                 if (IS_EVENT_SET(events, Event_Connection))
@@ -255,8 +260,14 @@ static void printevents(unsigned int events) {
                         printf("Instance ");
                 if (IS_EVENT_SET(events, Event_Invalid))
                         printf("Invalid ");
+                if (IS_EVENT_SET(events, Event_Link))
+                        printf("Link ");
                 if (IS_EVENT_SET(events, Event_Nonexist))
                         printf("Nonexist ");
+                if (IS_EVENT_SET(events, Event_PacketIn))
+                        printf("PacketIn ");
+                if (IS_EVENT_SET(events, Event_PacketOut))
+                        printf("PacketOut ");
                 if (IS_EVENT_SET(events, Event_Permission))
                         printf("Permission ");
                 if (IS_EVENT_SET(events, Event_Pid))
@@ -265,8 +276,12 @@ static void printevents(unsigned int events) {
                         printf("PPID ");
                 if (IS_EVENT_SET(events, Event_Resource))
                         printf("Resource ");
+                if (IS_EVENT_SET(events, Event_Saturation))
+                        printf("Saturation ");
                 if (IS_EVENT_SET(events, Event_Size))
                         printf("Size ");
+                if (IS_EVENT_SET(events, Event_Speed))
+                        printf("Speed ");
                 if (IS_EVENT_SET(events, Event_Status))
                         printf("Status ");
                 if (IS_EVENT_SET(events, Event_Timeout))
@@ -799,7 +814,7 @@ void Util_printRunList() {
                 for (c = Run.mmonits; c; c = c->next) {
                         printf("%s with timeout %d seconds%s%s%s%s%s%s",
                                c->url->url,
-                               c->timeout,
+                               c->timeout / 1000,
                                (c->ssl.use_ssl && c->ssl.version) ? " ssl version " : "",
                                (c->ssl.use_ssl && c->ssl.version) ? sslnames[c->ssl.version] : "",
                                c->ssl.certmd5?" server cert md5 sum ":"",
@@ -914,6 +929,8 @@ void Util_printService(Service_T s) {
                         printf(" %-20s = %s\n", "Pid file", s->path);
         } else if (s->type == TYPE_HOST) {
                 printf(" %-20s = %s\n", "Address", s->path);
+        } else if (s->type == TYPE_NET) {
+                printf(" %-20s = %s\n", "Interface", s->path);
         } else if (s->type != TYPE_SYSTEM) {
                 printf(" %-20s = %s\n", "Path", s->path);
         }
@@ -954,7 +971,7 @@ void Util_printService(Service_T s) {
                 printf(" timeout %d second(s)", s->restart->timeout);
                 printf("\n");
         }
-        if (s->type != TYPE_SYSTEM && s->type != TYPE_PROGRAM) {
+        if (s->type != TYPE_SYSTEM && s->type != TYPE_PROGRAM && s->type != TYPE_NET) {
                 StringBuffer_clear(buf);
                 printf(" %-20s = %s\n", "Existence", StringBuffer_toString(Util_printRule(buf, s->action_NONEXIST, "if does not exist")));
         }
@@ -963,11 +980,14 @@ void Util_printService(Service_T s) {
                 if (o->dependant != NULL)
                         printf(" %-20s = %s\n", "Depends on Service", o->dependant);
 
-        if (s->type == TYPE_PROCESS) {
+        for (Pid_T o = s->pidlist; o; o = o->next) {
                 StringBuffer_clear(buf);
-                printf(" %-20s = %s\n", "Pid", StringBuffer_toString(Util_printRule(buf, s->action_PID, "if changed")));
+                printf(" %-20s = %s\n", "Pid", StringBuffer_toString(Util_printRule(buf, o->action, "if changed")));
+        }
+
+        for (Pid_T o = s->ppidlist; o; o = o->next) {
                 StringBuffer_clear(buf);
-                printf(" %-20s = %s\n", "PPid", StringBuffer_toString(Util_printRule(buf, s->action_PPID, "if changed")));
+                printf(" %-20s = %s\n", "PPid", StringBuffer_toString(Util_printRule(buf, o->action, "if changed")));
         }
 
         if (s->type == TYPE_FILESYSTEM) {
@@ -1020,23 +1040,23 @@ void Util_printService(Service_T s) {
 
         for (Icmp_T o = s->icmplist; o; o = o->next) {
                 StringBuffer_clear(buf);
-                printf(" %-20s = %s\n", "Ping", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s count %d with timeout %d seconds]", icmpnames[o->type], o->count, o->timeout)));
+                printf(" %-20s = %s\n", "Ping", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [count %d with timeout %d seconds]", o->count, o->timeout / 1000)));
         }
 
         for (Port_T o = s->portlist; o; o = o->next) {
                 StringBuffer_clear(buf);
                 if (o->family == AF_INET) {
                         if (o->retry > 1)
-                                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s:%d%s [%s via %s] with timeout %d seconds and retry %d times]", o->hostname, o->port, o->request ? o->request : "", o->protocol->name, Util_portTypeDescription(o), o->timeout, o->retry)));
+                                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s:%d%s [%s via %s] with timeout %d seconds and retry %d times]", o->hostname, o->port, o->request ? o->request : "", o->protocol->name, Util_portTypeDescription(o), o->timeout / 1000, o->retry)));
                         else
-                                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s:%d%s [%s via %s] with timeout %d seconds]", o->hostname, o->port, o->request ? o->request : "", o->protocol->name, Util_portTypeDescription(o), o->timeout)));
+                                printf(" %-20s = %s\n", "Port", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s:%d%s [%s via %s] with timeout %d seconds]", o->hostname, o->port, o->request ? o->request : "", o->protocol->name, Util_portTypeDescription(o), o->timeout / 1000)));
                         if (o->SSL.certmd5 != NULL)
                                 printf(" %-20s = %s\n", "Server cert md5 sum", o->SSL.certmd5);
                 } else if (o->family == AF_UNIX) {
                         if (o->retry > 1)
-                                printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s [protocol %s] with timeout %d seconds and retry %d times]", o->pathname, o->protocol->name, o->timeout, o->retry)));
+                                printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s [protocol %s] with timeout %d seconds and retry %d times]", o->pathname, o->protocol->name, o->timeout / 1000, o->retry)));
                         else
-                                printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s [protocol %s] with timeout %d seconds]", o->pathname, o->protocol->name, o->timeout, o->retry)));
+                                printf(" %-20s = %s\n", "Unix Socket", StringBuffer_toString(Util_printRule(buf, o->action, "if failed [%s [protocol %s] with timeout %d seconds]", o->pathname, o->protocol->name, o->timeout / 1000, o->retry)));
                 }
         }
 
@@ -1062,6 +1082,57 @@ void Util_printService(Service_T s) {
                 );
         }
 
+        for (NetLinkStatus_T o = s->netlinkstatuslist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                printf(" %-20s = %s\n", "Link status", StringBuffer_toString(Util_printRule(buf, o->action, "if failed")));
+        }
+
+        for (NetLinkSpeed_T o = s->netlinkspeedlist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                printf(" %-20s = %s\n", "Link capacity", StringBuffer_toString(Util_printRule(buf, o->action, "if changed")));
+        }
+
+        for (NetLinkSaturation_T o = s->netlinksaturationlist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                printf(" %-20s = %s\n", "Link utilization", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %.1f%%", operatornames[o->operator], o->limit)));
+        }
+
+        for (Bandwidth_T o = s->uploadbyteslist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                if (o->range == TIME_SECOND) {
+                        printf(" %-20s = %s\n", "Upload bytes", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %s/s", operatornames[o->operator], Str_bytesToSize(o->limit, buffer))));
+                } else {
+                        printf(" %-20s = %s\n", "Total upload bytes", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %s in last %d %s(s)", operatornames[o->operator], Str_bytesToSize(o->limit, buffer), o->rangecount, Util_timestr(o->range))));
+                }
+        }
+
+        for (Bandwidth_T o = s->uploadpacketslist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                if (o->range == TIME_SECOND) {
+                        printf(" %-20s = %s\n", "Upload packets", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %lld packets/s", operatornames[o->operator], o->limit)));
+                } else {
+                        printf(" %-20s = %s\n", "Total upload packets", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %lld packets in last %d %s(s)", operatornames[o->operator], o->limit, o->rangecount, Util_timestr(o->range))));
+                }
+        }
+
+        for (Bandwidth_T o = s->downloadbyteslist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                if (o->range == TIME_SECOND) {
+                        printf(" %-20s = %s\n", "Download bytes", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %s/s", operatornames[o->operator], Str_bytesToSize(o->limit, buffer))));
+                } else {
+                        printf(" %-20s = %s\n", "Total download bytes", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %s in last %d %s(s)", operatornames[o->operator], Str_bytesToSize(o->limit, buffer), o->rangecount, Util_timestr(o->range))));
+                }
+        }
+
+        for (Bandwidth_T o = s->downloadpacketslist; o; o = o->next) {
+                StringBuffer_clear(buf);
+                if (o->range == TIME_SECOND) {
+                        printf(" %-20s = %s\n", "Download packets", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %lld packets/s", operatornames[o->operator], o->limit)));
+                } else {
+                        printf(" %-20s = %s\n", "Total downl. packets", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %lld packets in last %d %s(s)", operatornames[o->operator], o->limit, o->rangecount, Util_timestr(o->range))));
+                }
+        }
+
         for (Uptime_T o = s->uptimelist; o; o = o->next) {
                 StringBuffer_clear(buf);
                 printf(" %-20s = %s\n", "Uptime", StringBuffer_toString(Util_printRule(buf, o->action, "if %s %llu second(s)", operatornames[o->operator], o->uptime)));
@@ -1242,9 +1313,7 @@ char *Util_monitId(char *idfile) {
                 md5_context_t ctx;
                 char buf[STRLEN];
                 MD_T digest;
-                mode_t mask = umask(PRIVATEMASK);
                 file = fopen(idfile, "w");
-                umask(mask);
                 if (! file) {
                         LogError("Error opening the idfile '%s' -- %s\n", idfile, STRERROR);
                         return NULL;
@@ -1351,7 +1420,7 @@ int Util_isProcessRunning(Service_T s, int refresh) {
         if (pid > 0) {
                 if ((getpgid(pid) > -1) || (errno == EPERM))
                         return pid;
-                DEBUG("'%s' Error testing process id [%d] -- %s\n", s->name, pid, STRERROR);
+                DEBUG("'%s' process test failed [pid=%d] -- %s\n", s->name, pid, STRERROR);
         }
         Util_resetInfo(s);
         return 0;
@@ -1645,6 +1714,10 @@ void Util_resetInfo(Service_T s) {
                         s->inf->priv.process.total_cpu_percent = 0;
                         s->inf->priv.process.uptime = 0;
                         break;
+                case TYPE_NET:
+                        if (s->inf->priv.net.stats)
+                                NetStatistics_reset(s->inf->priv.net.stats);
+                        break;
                 default:
                         break;
         }
@@ -1666,7 +1739,6 @@ char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len) {
 
 
 int Util_evalQExpression(Operator_Type operator, long long left, long long right) {
-
         switch (operator) {
                 case Operator_Greater:
                         if (left > right)
@@ -1689,9 +1761,34 @@ int Util_evalQExpression(Operator_Type operator, long long left, long long right
                         LogError("Unknown comparison operator\n");
                         return FALSE;
         }
-
         return FALSE;
+}
 
+
+int Util_evalDoubleQExpression(Operator_Type operator, double left, double right) {
+        switch (operator) {
+                case Operator_Greater:
+                        if (left > right)
+                                return TRUE;
+                        break;
+                case Operator_Less:
+                        if (left < right)
+                                return TRUE;
+                        break;
+                case Operator_Equal:
+                        if (left == right)
+                                return TRUE;
+                        break;
+                case Operator_NotEqual:
+                case Operator_Changed:
+                        if (left != right)
+                                return TRUE;
+                        break;
+                default:
+                        LogError("Unknown comparison operator\n");
+                        return FALSE;
+        }
+        return FALSE;
 }
 
 
@@ -1700,6 +1797,7 @@ void Util_monitorSet(Service_T s) {
         if (s->monitor == MONITOR_NOT) {
                 s->monitor = MONITOR_INIT;
                 DEBUG("'%s' monitoring enabled\n", s->name);
+                State_save();
         }
 }
 
@@ -1718,6 +1816,7 @@ void Util_monitorUnset(Service_T s) {
         if (s->eventlist)
                 gc_event(&s->eventlist);
         Util_resetInfo(s);
+        State_save();
 }
 
 
@@ -1803,7 +1902,7 @@ char *Util_portTypeDescription(Port_T p) {
 
 char *Util_portDescription(Port_T p, char *buf, int bufsize) {
         if (p->family == AF_INET)
-                snprintf(buf, STRLEN, "INET[%s:%d%s]%s%s", p->hostname, p->port, p->request ? p->request : "", p->family == AF_INET ? " via " : "", p->family == AF_INET ? Util_portTypeDescription(p) : "");
+                snprintf(buf, STRLEN, "INET[%s:%d%s] via %s", p->hostname, p->port, p->request ? p->request : "", Util_portTypeDescription(p));
         else if (p->family == AF_UNIX)
                 snprintf(buf, STRLEN, "UNIX[%s]", p->pathname);
         else
@@ -1844,3 +1943,24 @@ int Util_getfqdnhostname(char *buf, unsigned len) {
         return 0;
 }
 
+
+const char *Util_timestr(int time) {
+        int i = 0;
+        struct mytimetable {
+                int id;
+                char *description;
+        } tt[]= {
+                {TIME_SECOND, "second"},
+                {TIME_MINUTE, "minute"},
+                {TIME_HOUR,   "hour"},
+                {TIME_DAY,    "day"},
+                {TIME_MONTH,  "month"},
+                {0}
+        };
+        do {
+                if (time == tt[i].id)
+                        return tt[i].description;
+        } while (tt[++i].description);
+        return NULL;
+}
+
